# korona-cloud-client

KoronaCloudClient - the Ruby gem for the KORONA.cloud API v3

Our api provides access to our cloud services

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.14.7
- Package version: 1.0.3
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build korona-cloud-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./korona-cloud-client-1.0.3.gem
```

(for development, run `gem install --dev ./korona-cloud-client-1.0.3.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'korona-cloud-client', '~> 1.0.3'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'korona-cloud-client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'korona-cloud-client'

# Setup authorization
KoronaCloudClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = KoronaCloudClient::AccountsApi.new
korona_account_id = 'korona_account_id_example' # String | account id of the KORONA.cloud account
account_id = 'account_id_example' # String | id of the related object (important: id should match the uuid-format)

begin
  #returns the single account
  result = api_instance.get_account(korona_account_id, account_id)
  p result
rescue KoronaCloudClient::ApiError => e
  puts "Exception when calling AccountsApi->get_account: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://www.koronacloud.com/web/api/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*KoronaCloudClient::AccountsApi* | [**get_account**](docs/AccountsApi.md#get_account) | **GET** /accounts/{koronaAccountId}/accounts/{accountId} | returns the single account
*KoronaCloudClient::AccountsApi* | [**get_accounts**](docs/AccountsApi.md#get_accounts) | **GET** /accounts/{koronaAccountId}/accounts | lists all accounts
*KoronaCloudClient::AdditionalReceiptInfoTypesApi* | [**get_additional_receipt_info_type**](docs/AdditionalReceiptInfoTypesApi.md#get_additional_receipt_info_type) | **GET** /accounts/{koronaAccountId}/additionalReceiptInfoTypes/{additionalReceiptInfoTypeId} | returns the single additional receipt info type
*KoronaCloudClient::AdditionalReceiptInfoTypesApi* | [**get_additional_receipt_info_types**](docs/AdditionalReceiptInfoTypesApi.md#get_additional_receipt_info_types) | **GET** /accounts/{koronaAccountId}/additionalReceiptInfoTypes | lists all additional receipt info types
*KoronaCloudClient::AssortmentsApi* | [**add_assortments**](docs/AssortmentsApi.md#add_assortments) | **POST** /accounts/{koronaAccountId}/assortments | adds a batch of new assortments
*KoronaCloudClient::AssortmentsApi* | [**delete_assortment**](docs/AssortmentsApi.md#delete_assortment) | **DELETE** /accounts/{koronaAccountId}/assortments/{assortmentId} | deletes the single assortment
*KoronaCloudClient::AssortmentsApi* | [**delete_assortments**](docs/AssortmentsApi.md#delete_assortments) | **DELETE** /accounts/{koronaAccountId}/assortments | deletes a batch of assortments
*KoronaCloudClient::AssortmentsApi* | [**get_assortment**](docs/AssortmentsApi.md#get_assortment) | **GET** /accounts/{koronaAccountId}/assortments/{assortmentId} | returns the single assortment
*KoronaCloudClient::AssortmentsApi* | [**get_assortments**](docs/AssortmentsApi.md#get_assortments) | **GET** /accounts/{koronaAccountId}/assortments | lists all assortments
*KoronaCloudClient::AssortmentsApi* | [**update_assortment**](docs/AssortmentsApi.md#update_assortment) | **PATCH** /accounts/{koronaAccountId}/assortments/{assortmentId} | updates the single assortment
*KoronaCloudClient::AssortmentsApi* | [**update_assortments**](docs/AssortmentsApi.md#update_assortments) | **PATCH** /accounts/{koronaAccountId}/assortments | updates a batch of assortments
*KoronaCloudClient::CashierRolesApi* | [**add_cashier_roles**](docs/CashierRolesApi.md#add_cashier_roles) | **POST** /accounts/{koronaAccountId}/cashierRoles | adds a batch of new cashier roles
*KoronaCloudClient::CashierRolesApi* | [**delete_cashier_role**](docs/CashierRolesApi.md#delete_cashier_role) | **DELETE** /accounts/{koronaAccountId}/cashierRoles/{cashierRoleId} | deletes the single cashier role
*KoronaCloudClient::CashierRolesApi* | [**delete_cashier_roles**](docs/CashierRolesApi.md#delete_cashier_roles) | **DELETE** /accounts/{koronaAccountId}/cashierRoles | deletes a batch of cashier roles
*KoronaCloudClient::CashierRolesApi* | [**get_cashier_role**](docs/CashierRolesApi.md#get_cashier_role) | **GET** /accounts/{koronaAccountId}/cashierRoles/{cashierRoleId} | returns the single cashier role
*KoronaCloudClient::CashierRolesApi* | [**get_cashier_roles**](docs/CashierRolesApi.md#get_cashier_roles) | **GET** /accounts/{koronaAccountId}/cashierRoles | lists all cashier roles
*KoronaCloudClient::CashierRolesApi* | [**update_cashier_role**](docs/CashierRolesApi.md#update_cashier_role) | **PATCH** /accounts/{koronaAccountId}/cashierRoles/{cashierRoleId} | updates the single cashier role
*KoronaCloudClient::CashierRolesApi* | [**update_cashier_roles**](docs/CashierRolesApi.md#update_cashier_roles) | **PATCH** /accounts/{koronaAccountId}/cashierRoles | updates a batch of cashier roles
*KoronaCloudClient::CashiersApi* | [**add_cashiers**](docs/CashiersApi.md#add_cashiers) | **POST** /accounts/{koronaAccountId}/cashiers | adds a batch of new cashiers
*KoronaCloudClient::CashiersApi* | [**delete_cashier**](docs/CashiersApi.md#delete_cashier) | **DELETE** /accounts/{koronaAccountId}/cashiers/{cashierId} | deletes the single cashier
*KoronaCloudClient::CashiersApi* | [**delete_cashiers**](docs/CashiersApi.md#delete_cashiers) | **DELETE** /accounts/{koronaAccountId}/cashiers | deletes a batch of cashiers
*KoronaCloudClient::CashiersApi* | [**get_cashier**](docs/CashiersApi.md#get_cashier) | **GET** /accounts/{koronaAccountId}/cashiers/{cashierId} | returns the single cashier
*KoronaCloudClient::CashiersApi* | [**get_cashiers**](docs/CashiersApi.md#get_cashiers) | **GET** /accounts/{koronaAccountId}/cashiers | lists all cashiers
*KoronaCloudClient::CashiersApi* | [**update_cashier**](docs/CashiersApi.md#update_cashier) | **PATCH** /accounts/{koronaAccountId}/cashiers/{cashierId} | updates the single cashier
*KoronaCloudClient::CashiersApi* | [**update_cashiers**](docs/CashiersApi.md#update_cashiers) | **PATCH** /accounts/{koronaAccountId}/cashiers | updates a batch of cashiers
*KoronaCloudClient::CommodityGroupsApi* | [**add_commodity_groups**](docs/CommodityGroupsApi.md#add_commodity_groups) | **POST** /accounts/{koronaAccountId}/commodityGroups | adds a batch of new commodity groups
*KoronaCloudClient::CommodityGroupsApi* | [**delete_commodity_group**](docs/CommodityGroupsApi.md#delete_commodity_group) | **DELETE** /accounts/{koronaAccountId}/commodityGroups/{commodityGroupId} | deletes the single commodity group
*KoronaCloudClient::CommodityGroupsApi* | [**delete_commodity_groups**](docs/CommodityGroupsApi.md#delete_commodity_groups) | **DELETE** /accounts/{koronaAccountId}/commodityGroups | deletes a batch of commodity groups
*KoronaCloudClient::CommodityGroupsApi* | [**get_commodity_group**](docs/CommodityGroupsApi.md#get_commodity_group) | **GET** /accounts/{koronaAccountId}/commodityGroups/{commodityGroupId} | returns the single commodity group
*KoronaCloudClient::CommodityGroupsApi* | [**get_commodity_groups**](docs/CommodityGroupsApi.md#get_commodity_groups) | **GET** /accounts/{koronaAccountId}/commodityGroups | lists all commodity groups
*KoronaCloudClient::CommodityGroupsApi* | [**update_commodity_group**](docs/CommodityGroupsApi.md#update_commodity_group) | **PATCH** /accounts/{koronaAccountId}/commodityGroups/{commodityGroupId} | updates the single commodity group
*KoronaCloudClient::CommodityGroupsApi* | [**update_commodity_groups**](docs/CommodityGroupsApi.md#update_commodity_groups) | **PATCH** /accounts/{koronaAccountId}/commodityGroups | updates a batch of commodity groups
*KoronaCloudClient::CurrenciesApi* | [**add_currencies**](docs/CurrenciesApi.md#add_currencies) | **POST** /accounts/{koronaAccountId}/currencies | adds a batch of new currencies
*KoronaCloudClient::CurrenciesApi* | [**delete_currencies**](docs/CurrenciesApi.md#delete_currencies) | **DELETE** /accounts/{koronaAccountId}/currencies | deletes a batch of currencies
*KoronaCloudClient::CurrenciesApi* | [**get_currencies**](docs/CurrenciesApi.md#get_currencies) | **GET** /accounts/{koronaAccountId}/currencies | lists all currencies
*KoronaCloudClient::CurrenciesApi* | [**get_currency**](docs/CurrenciesApi.md#get_currency) | **GET** /accounts/{koronaAccountId}/currencies/{currencyId} | returns the single currency
*KoronaCloudClient::CurrenciesApi* | [**update_currencies**](docs/CurrenciesApi.md#update_currencies) | **PATCH** /accounts/{koronaAccountId}/currencies | updates a batch of currencies
*KoronaCloudClient::CustomerGroupsApi* | [**get_customer_group**](docs/CustomerGroupsApi.md#get_customer_group) | **GET** /accounts/{koronaAccountId}/customerGroups/{customerGroupId} | returns the single customer group
*KoronaCloudClient::CustomerGroupsApi* | [**get_customer_groups**](docs/CustomerGroupsApi.md#get_customer_groups) | **GET** /accounts/{koronaAccountId}/customerGroups | lists all customer groups
*KoronaCloudClient::CustomerOrdersApi* | [**add_customer_orders**](docs/CustomerOrdersApi.md#add_customer_orders) | **POST** /accounts/{koronaAccountId}/customerOrders | adds a batch of new customer orders
*KoronaCloudClient::CustomerOrdersApi* | [**delete_customer_order**](docs/CustomerOrdersApi.md#delete_customer_order) | **DELETE** /accounts/{koronaAccountId}/customerOrders/{customerOrderId} | deletes the single customer order
*KoronaCloudClient::CustomerOrdersApi* | [**get_customer_order**](docs/CustomerOrdersApi.md#get_customer_order) | **GET** /accounts/{koronaAccountId}/customerOrders/{customerOrderId} | returns the single customer order
*KoronaCloudClient::CustomerOrdersApi* | [**get_customer_orders**](docs/CustomerOrdersApi.md#get_customer_orders) | **GET** /accounts/{koronaAccountId}/customerOrders | lists all customer orders
*KoronaCloudClient::CustomerOrdersApi* | [**update_customer_order**](docs/CustomerOrdersApi.md#update_customer_order) | **PATCH** /accounts/{koronaAccountId}/customerOrders/{customerOrderId} | updates the single customer order
*KoronaCloudClient::CustomerOrdersApi* | [**update_customer_orders**](docs/CustomerOrdersApi.md#update_customer_orders) | **PATCH** /accounts/{koronaAccountId}/customerOrders | updates a batch of customer orders
*KoronaCloudClient::CustomersApi* | [**add_customers**](docs/CustomersApi.md#add_customers) | **POST** /accounts/{koronaAccountId}/customers | adds a batch of new customers
*KoronaCloudClient::CustomersApi* | [**delete_customer**](docs/CustomersApi.md#delete_customer) | **DELETE** /accounts/{koronaAccountId}/customers/{customerId} | deletes the single customer
*KoronaCloudClient::CustomersApi* | [**delete_customers**](docs/CustomersApi.md#delete_customers) | **DELETE** /accounts/{koronaAccountId}/customers | deletes a batch of customers
*KoronaCloudClient::CustomersApi* | [**get_customer**](docs/CustomersApi.md#get_customer) | **GET** /accounts/{koronaAccountId}/customers/{customerId} | returns the single customer
*KoronaCloudClient::CustomersApi* | [**get_customers**](docs/CustomersApi.md#get_customers) | **GET** /accounts/{koronaAccountId}/customers | lists all customers
*KoronaCloudClient::CustomersApi* | [**update_customer**](docs/CustomersApi.md#update_customer) | **PATCH** /accounts/{koronaAccountId}/customers/{customerId} | updates the single customer
*KoronaCloudClient::CustomersApi* | [**update_customers**](docs/CustomersApi.md#update_customers) | **PATCH** /accounts/{koronaAccountId}/customers | updates a batch of customers
*KoronaCloudClient::DeliveryNotesApi* | [**add_delivery_notes**](docs/DeliveryNotesApi.md#add_delivery_notes) | **POST** /accounts/{koronaAccountId}/deliveryNotes | adds delivery notes
*KoronaCloudClient::DeliveryNotesApi* | [**book_delivery_note**](docs/DeliveryNotesApi.md#book_delivery_note) | **PATCH** /accounts/{koronaAccountId}/deliveryNotes/{deliveryNoteId}/book | book the single delivery note
*KoronaCloudClient::DeliveryNotesApi* | [**finalize_delivery_note**](docs/DeliveryNotesApi.md#finalize_delivery_note) | **PATCH** /accounts/{koronaAccountId}/deliveryNotes/{deliveryNoteId}/finalize | finalize the single delivery note
*KoronaCloudClient::DeliveryNotesApi* | [**get_delivery_note**](docs/DeliveryNotesApi.md#get_delivery_note) | **GET** /accounts/{koronaAccountId}/deliveryNotes/{deliveryNoteId} | returns a single delivery note
*KoronaCloudClient::DeliveryNotesApi* | [**get_delivery_notes**](docs/DeliveryNotesApi.md#get_delivery_notes) | **GET** /accounts/{koronaAccountId}/deliveryNotes | lists all delivery notes
*KoronaCloudClient::EconomicZonesApi* | [**add_economic_zones**](docs/EconomicZonesApi.md#add_economic_zones) | **POST** /accounts/{koronaAccountId}/economicZones | adds a batch of new economic zones
*KoronaCloudClient::EconomicZonesApi* | [**delete_economic_zones**](docs/EconomicZonesApi.md#delete_economic_zones) | **DELETE** /accounts/{koronaAccountId}/economicZones | deletes a batch of economic zones
*KoronaCloudClient::EconomicZonesApi* | [**get_economic_zone**](docs/EconomicZonesApi.md#get_economic_zone) | **GET** /accounts/{koronaAccountId}/economicZones/{economicZoneId} | returns the single economic zone
*KoronaCloudClient::EconomicZonesApi* | [**get_economic_zones**](docs/EconomicZonesApi.md#get_economic_zones) | **GET** /accounts/{koronaAccountId}/economicZones | lists all economic zones
*KoronaCloudClient::EconomicZonesApi* | [**update_economic_zones**](docs/EconomicZonesApi.md#update_economic_zones) | **PATCH** /accounts/{koronaAccountId}/economicZones | updates a batch of economic zones
*KoronaCloudClient::ExternalSystemCallsApi* | [**add_external_system_calls**](docs/ExternalSystemCallsApi.md#add_external_system_calls) | **POST** /accounts/{koronaAccountId}/externalSystemCalls | adds a batch of new external system calls
*KoronaCloudClient::ExternalSystemCallsApi* | [**delete_external_system_call**](docs/ExternalSystemCallsApi.md#delete_external_system_call) | **DELETE** /accounts/{koronaAccountId}/externalSystemCalls/{externalSystemCallId} | deletes a single external system call
*KoronaCloudClient::ExternalSystemCallsApi* | [**delete_external_system_calls**](docs/ExternalSystemCallsApi.md#delete_external_system_calls) | **DELETE** /accounts/{koronaAccountId}/externalSystemCalls | deletes a batch of external system calls
*KoronaCloudClient::ExternalSystemCallsApi* | [**get_external_system_call**](docs/ExternalSystemCallsApi.md#get_external_system_call) | **GET** /accounts/{koronaAccountId}/externalSystemCalls/{externalSystemCallId} | returns a single external system call
*KoronaCloudClient::ExternalSystemCallsApi* | [**get_external_system_calls**](docs/ExternalSystemCallsApi.md#get_external_system_calls) | **GET** /accounts/{koronaAccountId}/externalSystemCalls | lists all external system calls
*KoronaCloudClient::ExternalSystemCallsApi* | [**update_external_system_call**](docs/ExternalSystemCallsApi.md#update_external_system_call) | **PATCH** /accounts/{koronaAccountId}/externalSystemCalls/{externalSystemCallId} | updates the single external system call
*KoronaCloudClient::ExternalSystemCallsApi* | [**update_external_system_calls**](docs/ExternalSystemCallsApi.md#update_external_system_calls) | **PATCH** /accounts/{koronaAccountId}/externalSystemCalls | updates a batch of external system calls
*KoronaCloudClient::FiscalUnitsApi* | [**add_fiscal_units**](docs/FiscalUnitsApi.md#add_fiscal_units) | **POST** /accounts/{koronaAccountId}/fiscalUnits | adds a batch of fiscal units
*KoronaCloudClient::FiscalUnitsApi* | [**get_fiscal_unit**](docs/FiscalUnitsApi.md#get_fiscal_unit) | **GET** /accounts/{koronaAccountId}/fiscalUnits/{fiscalUnitId} | returns the single fiscal unit
*KoronaCloudClient::FiscalUnitsApi* | [**get_fiscal_units**](docs/FiscalUnitsApi.md#get_fiscal_units) | **GET** /accounts/{koronaAccountId}/fiscalUnits | lists all fiscal units
*KoronaCloudClient::FiscalUnitsApi* | [**update_fiscal_unit**](docs/FiscalUnitsApi.md#update_fiscal_unit) | **PATCH** /accounts/{koronaAccountId}/fiscalUnits/{fiscalUnitId} | updates the fiscal unit
*KoronaCloudClient::FiscalUnitsApi* | [**update_fiscal_units**](docs/FiscalUnitsApi.md#update_fiscal_units) | **PATCH** /accounts/{koronaAccountId}/fiscalUnits | updates a batch of fiscal units
*KoronaCloudClient::ImagesApi* | [**get_image**](docs/ImagesApi.md#get_image) | **GET** /accounts/{koronaAccountId}/images/{imageId} | displays the image
*KoronaCloudClient::InfoTextsApi* | [**add_info_texts**](docs/InfoTextsApi.md#add_info_texts) | **POST** /accounts/{koronaAccountId}/infoTexts | adds a batch of new info texts
*KoronaCloudClient::InfoTextsApi* | [**delete_info_texts**](docs/InfoTextsApi.md#delete_info_texts) | **DELETE** /accounts/{koronaAccountId}/infoTexts | deletes a batch of info texts
*KoronaCloudClient::InfoTextsApi* | [**get_info_text**](docs/InfoTextsApi.md#get_info_text) | **GET** /accounts/{koronaAccountId}/infoTexts/{infoTextId} | returns the single info text
*KoronaCloudClient::InfoTextsApi* | [**get_info_texts**](docs/InfoTextsApi.md#get_info_texts) | **GET** /accounts/{koronaAccountId}/infoTexts | lists all info texts
*KoronaCloudClient::InfoTextsApi* | [**update_info_texts**](docs/InfoTextsApi.md#update_info_texts) | **PATCH** /accounts/{koronaAccountId}/infoTexts | updates a batch of info texts
*KoronaCloudClient::InventoriesApi* | [**add_inventories**](docs/InventoriesApi.md#add_inventories) | **POST** /accounts/{koronaAccountId}/inventories | adds a batch of new inventories
*KoronaCloudClient::InventoriesApi* | [**add_inventory_inventory_list_items**](docs/InventoriesApi.md#add_inventory_inventory_list_items) | **POST** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items | adds inventory list items
*KoronaCloudClient::InventoriesApi* | [**delete_inventory**](docs/InventoriesApi.md#delete_inventory) | **DELETE** /accounts/{koronaAccountId}/inventories/{inventoryId} | deletes the single inventory (only allowed if hasBookedReceipts=false)
*KoronaCloudClient::InventoriesApi* | [**delete_inventory_inventory_list_item**](docs/InventoriesApi.md#delete_inventory_inventory_list_item) | **DELETE** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items/{productId} | deletes the single inventory list item
*KoronaCloudClient::InventoriesApi* | [**get_inventories**](docs/InventoriesApi.md#get_inventories) | **GET** /accounts/{koronaAccountId}/inventories | lists all inventories
*KoronaCloudClient::InventoriesApi* | [**get_inventory**](docs/InventoriesApi.md#get_inventory) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId} | returns the single inventory
*KoronaCloudClient::InventoriesApi* | [**get_inventory_inventory_list**](docs/InventoriesApi.md#get_inventory_inventory_list) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId} | returns the single inventory list
*KoronaCloudClient::InventoriesApi* | [**get_inventory_inventory_list_item**](docs/InventoriesApi.md#get_inventory_inventory_list_item) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items/{productId} | returns the single inventory list item
*KoronaCloudClient::InventoriesApi* | [**get_inventory_inventory_list_items**](docs/InventoriesApi.md#get_inventory_inventory_list_items) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items | lists all inventory list items
*KoronaCloudClient::InventoriesApi* | [**get_inventory_inventory_lists**](docs/InventoriesApi.md#get_inventory_inventory_lists) | **GET** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists | lists all inventory lists
*KoronaCloudClient::InventoriesApi* | [**update_inventory**](docs/InventoriesApi.md#update_inventory) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId} | updates the single inventory
*KoronaCloudClient::InventoriesApi* | [**update_inventory_inventory_list**](docs/InventoriesApi.md#update_inventory_inventory_list) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId} | updates the single inventory list
*KoronaCloudClient::InventoriesApi* | [**update_inventory_inventory_list_item**](docs/InventoriesApi.md#update_inventory_inventory_list_item) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items/{productId} | updates the single inventory list item
*KoronaCloudClient::InventoriesApi* | [**update_inventory_inventory_list_items**](docs/InventoriesApi.md#update_inventory_inventory_list_items) | **PATCH** /accounts/{koronaAccountId}/inventories/{inventoryId}/inventoryLists/{inventoryListId}/items | updates inventory list items (property [product] required))
*KoronaCloudClient::KoronaAccountApi* | [**get_korona_account**](docs/KoronaAccountApi.md#get_korona_account) | **GET** /accounts/{koronaAccountId} | returns the single korona account
*KoronaCloudClient::OrganizationalUnitsApi* | [**add_organizational_unit_day_ratings**](docs/OrganizationalUnitsApi.md#add_organizational_unit_day_ratings) | **POST** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings | adds a batch of new day ratings
*KoronaCloudClient::OrganizationalUnitsApi* | [**delete_organizational_unit_day_rating**](docs/OrganizationalUnitsApi.md#delete_organizational_unit_day_rating) | **DELETE** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings/{dayRatingIdOrDate} | deletes the single day rating by its id or date
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_unit**](docs/OrganizationalUnitsApi.md#get_organizational_unit) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId} | returns the single organizational unit
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_unit_day_rating**](docs/OrganizationalUnitsApi.md#get_organizational_unit_day_rating) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings/{dayRatingIdOrDate} | returns the single day rating by its id or date
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_unit_day_ratings**](docs/OrganizationalUnitsApi.md#get_organizational_unit_day_ratings) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings | lists all organizational unit related day ratings
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_unit_inventory_lists**](docs/OrganizationalUnitsApi.md#get_organizational_unit_inventory_lists) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/inventoryLists | lists the inventory lists belonging to the organizational unit (KORONA.retail required)
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_unit_product_stocks**](docs/OrganizationalUnitsApi.md#get_organizational_unit_product_stocks) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/productStocks | lists the product stocks of the organizational unit, in case it contains a warehouse (KORONA.retail required)
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_unit_stock_receipts**](docs/OrganizationalUnitsApi.md#get_organizational_unit_stock_receipts) | **GET** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/stockReceipts | lists the stock receipts belonging to the organizational unit (KORONA.retail required)
*KoronaCloudClient::OrganizationalUnitsApi* | [**get_organizational_units**](docs/OrganizationalUnitsApi.md#get_organizational_units) | **GET** /accounts/{koronaAccountId}/organizationalUnits | lists all organizational units
*KoronaCloudClient::OrganizationalUnitsApi* | [**update_organizational_unit_day_rating**](docs/OrganizationalUnitsApi.md#update_organizational_unit_day_rating) | **PATCH** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings/{dayRatingIdOrDate} | updates the day rating by its id or date
*KoronaCloudClient::OrganizationalUnitsApi* | [**update_organizational_unit_day_ratings**](docs/OrganizationalUnitsApi.md#update_organizational_unit_day_ratings) | **PATCH** /accounts/{koronaAccountId}/organizationalUnits/{organizationalUnitId}/dayRatings | updates a batch of day ratings
*KoronaCloudClient::PaymentMethodsApi* | [**get_payment_method**](docs/PaymentMethodsApi.md#get_payment_method) | **GET** /accounts/{koronaAccountId}/paymentMethods/{paymentMethodId} | returns the single payment method
*KoronaCloudClient::PaymentMethodsApi* | [**get_payment_methods**](docs/PaymentMethodsApi.md#get_payment_methods) | **GET** /accounts/{koronaAccountId}/paymentMethods | lists all payment methods
*KoronaCloudClient::PointsOfSaleApi* | [**add_point_of_sale_end_of_day_statements**](docs/PointsOfSaleApi.md#add_point_of_sale_end_of_day_statements) | **POST** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/endOfDayStatements | adds a batch of point of sale-related end-of-day-statements
*KoronaCloudClient::PointsOfSaleApi* | [**add_point_of_sale_receipts**](docs/PointsOfSaleApi.md#add_point_of_sale_receipts) | **POST** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/receipts | adds a batch of point of sale-related receipts
*KoronaCloudClient::PointsOfSaleApi* | [**get_point_of_sale**](docs/PointsOfSaleApi.md#get_point_of_sale) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId} | returns the single point of sale
*KoronaCloudClient::PointsOfSaleApi* | [**get_point_of_sale_end_of_day_statements**](docs/PointsOfSaleApi.md#get_point_of_sale_end_of_day_statements) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/endOfDayStatements | lists all point of sale-related end-of-day-statements
*KoronaCloudClient::PointsOfSaleApi* | [**get_point_of_sale_receipt**](docs/PointsOfSaleApi.md#get_point_of_sale_receipt) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/receipts/{receiptId} | returns the single point of sale-related receipt
*KoronaCloudClient::PointsOfSaleApi* | [**get_point_of_sale_receipts**](docs/PointsOfSaleApi.md#get_point_of_sale_receipts) | **GET** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId}/receipts | lists all point of sale-related receipts
*KoronaCloudClient::PointsOfSaleApi* | [**get_points_of_sale**](docs/PointsOfSaleApi.md#get_points_of_sale) | **GET** /accounts/{koronaAccountId}/pointsOfSale | lists all points of sale
*KoronaCloudClient::PointsOfSaleApi* | [**update_point_of_sale**](docs/PointsOfSaleApi.md#update_point_of_sale) | **PATCH** /accounts/{koronaAccountId}/pointsOfSale/{pointOfSaleId} | updates a point of sale (works only for coupling (attribute 'couplingId') or updating device information (attribute 'deviceInformation'))
*KoronaCloudClient::PriceGroupsApi* | [**add_price_groups**](docs/PriceGroupsApi.md#add_price_groups) | **POST** /accounts/{koronaAccountId}/priceGroups | adds a batch of new price groups
*KoronaCloudClient::PriceGroupsApi* | [**delete_price_groups**](docs/PriceGroupsApi.md#delete_price_groups) | **DELETE** /accounts/{koronaAccountId}/priceGroups | deletes a batch of price groups
*KoronaCloudClient::PriceGroupsApi* | [**get_price_group**](docs/PriceGroupsApi.md#get_price_group) | **GET** /accounts/{koronaAccountId}/priceGroups/{priceGroupId} | returns the single price group
*KoronaCloudClient::PriceGroupsApi* | [**get_price_groups**](docs/PriceGroupsApi.md#get_price_groups) | **GET** /accounts/{koronaAccountId}/priceGroups | lists all price groups
*KoronaCloudClient::PriceGroupsApi* | [**update_price_groups**](docs/PriceGroupsApi.md#update_price_groups) | **PATCH** /accounts/{koronaAccountId}/priceGroups | updates a batch of price groups
*KoronaCloudClient::ProductionTypesApi* | [**add_production_types**](docs/ProductionTypesApi.md#add_production_types) | **POST** /accounts/{koronaAccountId}/productionTypes | adds a batch of new production types
*KoronaCloudClient::ProductionTypesApi* | [**delete_production_types**](docs/ProductionTypesApi.md#delete_production_types) | **DELETE** /accounts/{koronaAccountId}/productionTypes | deletes a batch of production types
*KoronaCloudClient::ProductionTypesApi* | [**get_production_type**](docs/ProductionTypesApi.md#get_production_type) | **GET** /accounts/{koronaAccountId}/productionTypes/{productionTypeId} | returns the single production type
*KoronaCloudClient::ProductionTypesApi* | [**get_production_types**](docs/ProductionTypesApi.md#get_production_types) | **GET** /accounts/{koronaAccountId}/productionTypes | lists all production types
*KoronaCloudClient::ProductionTypesApi* | [**update_production_types**](docs/ProductionTypesApi.md#update_production_types) | **PATCH** /accounts/{koronaAccountId}/productionTypes | updates a batch of production types
*KoronaCloudClient::ProductsApi* | [**add_products**](docs/ProductsApi.md#add_products) | **POST** /accounts/{koronaAccountId}/products | adds a batch of new products
*KoronaCloudClient::ProductsApi* | [**delete_product**](docs/ProductsApi.md#delete_product) | **DELETE** /accounts/{koronaAccountId}/products/{productId} | deletes the single product
*KoronaCloudClient::ProductsApi* | [**delete_products**](docs/ProductsApi.md#delete_products) | **DELETE** /accounts/{koronaAccountId}/products | deletes a batch of products
*KoronaCloudClient::ProductsApi* | [**get_product**](docs/ProductsApi.md#get_product) | **GET** /accounts/{koronaAccountId}/products/{productId} | returns the single product
*KoronaCloudClient::ProductsApi* | [**get_product_stocks**](docs/ProductsApi.md#get_product_stocks) | **GET** /accounts/{koronaAccountId}/products/{productId}/stocks | lists the product stocks in different warehouses (KORONA.retail required)
*KoronaCloudClient::ProductsApi* | [**get_products**](docs/ProductsApi.md#get_products) | **GET** /accounts/{koronaAccountId}/products | lists all products
*KoronaCloudClient::ProductsApi* | [**update_product**](docs/ProductsApi.md#update_product) | **PATCH** /accounts/{koronaAccountId}/products/{productId} | updates the single product
*KoronaCloudClient::ProductsApi* | [**update_products**](docs/ProductsApi.md#update_products) | **PATCH** /accounts/{koronaAccountId}/products | updates a batch of products
*KoronaCloudClient::ReceiptsApi* | [**get_receipt**](docs/ReceiptsApi.md#get_receipt) | **GET** /accounts/{koronaAccountId}/receipts/{receiptId} | returns the single receipt
*KoronaCloudClient::ReceiptsApi* | [**get_receipts**](docs/ReceiptsApi.md#get_receipts) | **GET** /accounts/{koronaAccountId}/receipts | lists all receipts
*KoronaCloudClient::SalesTaxesApi* | [**add_sales_taxes**](docs/SalesTaxesApi.md#add_sales_taxes) | **POST** /accounts/{koronaAccountId}/salesTaxes | adds a batch of new sales taxes
*KoronaCloudClient::SalesTaxesApi* | [**delete_sales_taxes**](docs/SalesTaxesApi.md#delete_sales_taxes) | **DELETE** /accounts/{koronaAccountId}/salesTaxes | deletes a batch of sales taxes
*KoronaCloudClient::SalesTaxesApi* | [**get_sales_tax**](docs/SalesTaxesApi.md#get_sales_tax) | **GET** /accounts/{koronaAccountId}/salesTaxes/{salesTaxId} | returns the single sales tax
*KoronaCloudClient::SalesTaxesApi* | [**get_sales_taxes**](docs/SalesTaxesApi.md#get_sales_taxes) | **GET** /accounts/{koronaAccountId}/salesTaxes | lists all sales taxes
*KoronaCloudClient::SalesTaxesApi* | [**update_sales_taxes**](docs/SalesTaxesApi.md#update_sales_taxes) | **PATCH** /accounts/{koronaAccountId}/salesTaxes | updates a batch of sales taxes
*KoronaCloudClient::SectorsApi* | [**add_sectors**](docs/SectorsApi.md#add_sectors) | **POST** /accounts/{koronaAccountId}/sectors | adds a batch of new sectors
*KoronaCloudClient::SectorsApi* | [**delete_sectors**](docs/SectorsApi.md#delete_sectors) | **DELETE** /accounts/{koronaAccountId}/sectors | deletes a batch of sectors
*KoronaCloudClient::SectorsApi* | [**get_sector**](docs/SectorsApi.md#get_sector) | **GET** /accounts/{koronaAccountId}/sectors/{sectorId} | returns the single sector
*KoronaCloudClient::SectorsApi* | [**get_sectors**](docs/SectorsApi.md#get_sectors) | **GET** /accounts/{koronaAccountId}/sectors | lists all sectors
*KoronaCloudClient::SectorsApi* | [**update_sectors**](docs/SectorsApi.md#update_sectors) | **PATCH** /accounts/{koronaAccountId}/sectors | updates a batch of sectors
*KoronaCloudClient::StatisticsApi* | [**get_revenue**](docs/StatisticsApi.md#get_revenue) | **GET** /accounts/{koronaAccountId}/statistics/revenueData | returns information about the revenue in the given period
*KoronaCloudClient::StatisticsApi* | [**get_revenue_for_customer_groups**](docs/StatisticsApi.md#get_revenue_for_customer_groups) | **GET** /accounts/{koronaAccountId}/statistics/revenueDataForCustomerGroups | returns the turnover per customer group during the given period
*KoronaCloudClient::StatisticsApi* | [**get_revenue_hourly**](docs/StatisticsApi.md#get_revenue_hourly) | **GET** /accounts/{koronaAccountId}/statistics/revenueDataHourly | returns the turnover per hour during the given period
*KoronaCloudClient::StatisticsApi* | [**get_top_seller**](docs/StatisticsApi.md#get_top_seller) | **GET** /accounts/{koronaAccountId}/statistics/topSeller | returns the top-seller
*KoronaCloudClient::StockOrdersApi* | [**book_stock_order**](docs/StockOrdersApi.md#book_stock_order) | **PATCH** /accounts/{koronaAccountId}/stockOrders/{stockOrderId}/book | book the single stock order
*KoronaCloudClient::StockOrdersApi* | [**get_stock_order**](docs/StockOrdersApi.md#get_stock_order) | **GET** /accounts/{koronaAccountId}/stockOrders/{stockOrderId} | returns a single stock order
*KoronaCloudClient::StockOrdersApi* | [**get_stock_orders**](docs/StockOrdersApi.md#get_stock_orders) | **GET** /accounts/{koronaAccountId}/stockOrders | lists all stock orders
*KoronaCloudClient::StockReceiptsApi* | [**add_stock_receipt_items**](docs/StockReceiptsApi.md#add_stock_receipt_items) | **POST** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items | adds stock-receipt items
*KoronaCloudClient::StockReceiptsApi* | [**add_stock_receipts**](docs/StockReceiptsApi.md#add_stock_receipts) | **POST** /accounts/{koronaAccountId}/stockReceipts | adds stock-receipts
*KoronaCloudClient::StockReceiptsApi* | [**book_stock_receipt**](docs/StockReceiptsApi.md#book_stock_receipt) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/book | book the single stock-receipt
*KoronaCloudClient::StockReceiptsApi* | [**delete_stock_receipt_item**](docs/StockReceiptsApi.md#delete_stock_receipt_item) | **DELETE** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items/{productId} | deletes the single stock-receipt item
*KoronaCloudClient::StockReceiptsApi* | [**get_stock_receipt**](docs/StockReceiptsApi.md#get_stock_receipt) | **GET** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId} | returns the single stock-receipt
*KoronaCloudClient::StockReceiptsApi* | [**get_stock_receipt_item**](docs/StockReceiptsApi.md#get_stock_receipt_item) | **GET** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items/{productId} | returns the single stock-receipt item
*KoronaCloudClient::StockReceiptsApi* | [**get_stock_receipt_items**](docs/StockReceiptsApi.md#get_stock_receipt_items) | **GET** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items | lists all stock-receipt items
*KoronaCloudClient::StockReceiptsApi* | [**get_stock_receipts**](docs/StockReceiptsApi.md#get_stock_receipts) | **GET** /accounts/{koronaAccountId}/stockReceipts | lists all stock-receipts
*KoronaCloudClient::StockReceiptsApi* | [**update_stock_receipt**](docs/StockReceiptsApi.md#update_stock_receipt) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId} | updates the single stock-receipt
*KoronaCloudClient::StockReceiptsApi* | [**update_stock_receipt_item**](docs/StockReceiptsApi.md#update_stock_receipt_item) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items/{productId} | updates the single stock-receipt item
*KoronaCloudClient::StockReceiptsApi* | [**update_stock_receipt_items**](docs/StockReceiptsApi.md#update_stock_receipt_items) | **PATCH** /accounts/{koronaAccountId}/stockReceipts/{stockReceiptId}/items | updates stock-receipt items
*KoronaCloudClient::SuppliersApi* | [**add_suppliers**](docs/SuppliersApi.md#add_suppliers) | **POST** /accounts/{koronaAccountId}/suppliers | adds a batch of new suppliers
*KoronaCloudClient::SuppliersApi* | [**delete_suppliers**](docs/SuppliersApi.md#delete_suppliers) | **DELETE** /accounts/{koronaAccountId}/suppliers | deletes a batch of suppliers
*KoronaCloudClient::SuppliersApi* | [**get_supplier**](docs/SuppliersApi.md#get_supplier) | **GET** /accounts/{koronaAccountId}/suppliers/{supplierId} | returns the single supplier
*KoronaCloudClient::SuppliersApi* | [**get_suppliers**](docs/SuppliersApi.md#get_suppliers) | **GET** /accounts/{koronaAccountId}/suppliers | lists all suppliers
*KoronaCloudClient::SuppliersApi* | [**update_suppliers**](docs/SuppliersApi.md#update_suppliers) | **PATCH** /accounts/{koronaAccountId}/suppliers | updates a batch of suppliers
*KoronaCloudClient::TagsApi* | [**add_tags**](docs/TagsApi.md#add_tags) | **POST** /accounts/{koronaAccountId}/tags | adds a batch of new tags
*KoronaCloudClient::TagsApi* | [**delete_tag**](docs/TagsApi.md#delete_tag) | **DELETE** /accounts/{koronaAccountId}/tags/{tagId} | deletes the single tag
*KoronaCloudClient::TagsApi* | [**delete_tags**](docs/TagsApi.md#delete_tags) | **DELETE** /accounts/{koronaAccountId}/tags | deletes a batch of tags
*KoronaCloudClient::TagsApi* | [**get_tag**](docs/TagsApi.md#get_tag) | **GET** /accounts/{koronaAccountId}/tags/{tagId} | returns the single tag
*KoronaCloudClient::TagsApi* | [**get_tags**](docs/TagsApi.md#get_tags) | **GET** /accounts/{koronaAccountId}/tags | lists all tags
*KoronaCloudClient::TagsApi* | [**update_tag**](docs/TagsApi.md#update_tag) | **PATCH** /accounts/{koronaAccountId}/tags/{tagId} | updates the single tag
*KoronaCloudClient::TagsApi* | [**update_tags**](docs/TagsApi.md#update_tags) | **PATCH** /accounts/{koronaAccountId}/tags | updates a batch of tags
*KoronaCloudClient::TicketCreationApi* | [**add_creation_task**](docs/TicketCreationApi.md#add_creation_task) | **POST** /accounts/{koronaAccountId}/ticketCreation | adds a creation task
*KoronaCloudClient::TicketCreationApi* | [**get_creation_tasks**](docs/TicketCreationApi.md#get_creation_tasks) | **GET** /accounts/{koronaAccountId}/ticketCreation | creation tasks, personalization will always be empty for technical reasons
*KoronaCloudClient::TicketingApi* | [**add_entry_gates**](docs/TicketingApi.md#add_entry_gates) | **POST** /accounts/{koronaAccountId}/entryGates | adds a batch of new entry gates
*KoronaCloudClient::TicketingApi* | [**add_events**](docs/TicketingApi.md#add_events) | **POST** /accounts/{koronaAccountId}/events | adds a batch of new events
*KoronaCloudClient::TicketingApi* | [**add_or_update_attendances**](docs/TicketingApi.md#add_or_update_attendances) | **POST** /accounts/{koronaAccountId}/attendances | updates/adds attendances
*KoronaCloudClient::TicketingApi* | [**add_ticket_definitions**](docs/TicketingApi.md#add_ticket_definitions) | **POST** /accounts/{koronaAccountId}/ticketDefinitions | adds a batch of new ticket definitions
*KoronaCloudClient::TicketingApi* | [**cancel_attendance**](docs/TicketingApi.md#cancel_attendance) | **DELETE** /accounts/{koronaAccountId}/attendances/{attendanceId} | cancel the attendance
*KoronaCloudClient::TicketingApi* | [**delete_entry_gates**](docs/TicketingApi.md#delete_entry_gates) | **DELETE** /accounts/{koronaAccountId}/entryGates | deletes a batch of entry gates
*KoronaCloudClient::TicketingApi* | [**delete_event**](docs/TicketingApi.md#delete_event) | **DELETE** /accounts/{koronaAccountId}/events/{eventId} | deletes the single event
*KoronaCloudClient::TicketingApi* | [**delete_ticket_definition**](docs/TicketingApi.md#delete_ticket_definition) | **DELETE** /accounts/{koronaAccountId}/ticketDefinitions/{ticketDefinitionId} | deletes the single ticket definition
*KoronaCloudClient::TicketingApi* | [**delete_ticket_definitions**](docs/TicketingApi.md#delete_ticket_definitions) | **DELETE** /accounts/{koronaAccountId}/ticketDefinitions | deletes a batch of ticket definitions
*KoronaCloudClient::TicketingApi* | [**get_attendance**](docs/TicketingApi.md#get_attendance) | **GET** /accounts/{koronaAccountId}/attendances/{attendanceId} | returns the single attendance
*KoronaCloudClient::TicketingApi* | [**get_attendances**](docs/TicketingApi.md#get_attendances) | **GET** /accounts/{koronaAccountId}/attendances | lists all attendances
*KoronaCloudClient::TicketingApi* | [**get_entry_gate**](docs/TicketingApi.md#get_entry_gate) | **GET** /accounts/{koronaAccountId}/entryGates/{entryGateId} | returns the single entry gate
*KoronaCloudClient::TicketingApi* | [**get_entry_gates**](docs/TicketingApi.md#get_entry_gates) | **GET** /accounts/{koronaAccountId}/entryGates | lists all entry gates
*KoronaCloudClient::TicketingApi* | [**get_event**](docs/TicketingApi.md#get_event) | **GET** /accounts/{koronaAccountId}/events/{eventId} | returns the single event
*KoronaCloudClient::TicketingApi* | [**get_events**](docs/TicketingApi.md#get_events) | **GET** /accounts/{koronaAccountId}/events | lists all events
*KoronaCloudClient::TicketingApi* | [**get_ticket_definition**](docs/TicketingApi.md#get_ticket_definition) | **GET** /accounts/{koronaAccountId}/ticketDefinitions/{ticketDefinitionId} | returns the single ticket definition
*KoronaCloudClient::TicketingApi* | [**get_ticket_definitions**](docs/TicketingApi.md#get_ticket_definitions) | **GET** /accounts/{koronaAccountId}/ticketDefinitions | lists all ticket definitions
*KoronaCloudClient::TicketingApi* | [**get_tickets**](docs/TicketingApi.md#get_tickets) | **GET** /accounts/{koronaAccountId}/tickets | lists all tickets
*KoronaCloudClient::TicketingApi* | [**lock_ticket**](docs/TicketingApi.md#lock_ticket) | **DELETE** /accounts/{koronaAccountId}/tickets/{ticketNumber} | locks the single ticket
*KoronaCloudClient::TicketingApi* | [**unlock_ticket**](docs/TicketingApi.md#unlock_ticket) | **POST** /accounts/{koronaAccountId}/tickets/{ticketNumber} | unlocks the single ticket
*KoronaCloudClient::TicketingApi* | [**update_entry_gates**](docs/TicketingApi.md#update_entry_gates) | **PATCH** /accounts/{koronaAccountId}/entryGates | updates a batch of entry gates
*KoronaCloudClient::TicketingApi* | [**update_event**](docs/TicketingApi.md#update_event) | **PATCH** /accounts/{koronaAccountId}/events/{eventId} | updates the single event
*KoronaCloudClient::TicketingApi* | [**update_events**](docs/TicketingApi.md#update_events) | **PATCH** /accounts/{koronaAccountId}/events | updates a batch of events
*KoronaCloudClient::TicketingApi* | [**update_ticket**](docs/TicketingApi.md#update_ticket) | **PATCH** /accounts/{koronaAccountId}/tickets/{ticketNumber} | updates the single ticket
*KoronaCloudClient::TicketingApi* | [**update_ticket_definitions**](docs/TicketingApi.md#update_ticket_definitions) | **PATCH** /accounts/{koronaAccountId}/ticketDefinitions | updates a batch of ticket definitions
*KoronaCloudClient::TimeTrackingApi* | [**add_entities**](docs/TimeTrackingApi.md#add_entities) | **POST** /accounts/{koronaAccountId}/timeTrackingEntities | adds a batch of new time tracking entities
*KoronaCloudClient::TimeTrackingApi* | [**add_entries**](docs/TimeTrackingApi.md#add_entries) | **POST** /accounts/{koronaAccountId}/timeTrackingEntries | adds a batch of new time tracking entries
*KoronaCloudClient::TimeTrackingApi* | [**get_entities**](docs/TimeTrackingApi.md#get_entities) | **GET** /accounts/{koronaAccountId}/timeTrackingEntities | lists time tracking entities
*KoronaCloudClient::TimeTrackingApi* | [**get_entries**](docs/TimeTrackingApi.md#get_entries) | **GET** /accounts/{koronaAccountId}/timeTrackingEntries | lists time tracking entries
*KoronaCloudClient::TimeTrackingApi* | [**get_time_tracking_entity**](docs/TimeTrackingApi.md#get_time_tracking_entity) | **GET** /accounts/{koronaAccountId}/timeTrackingEntities/{timeTrackingEntityId} | returns a single time tracking entity
*KoronaCloudClient::TimeTrackingApi* | [**get_time_tracking_entry**](docs/TimeTrackingApi.md#get_time_tracking_entry) | **GET** /accounts/{koronaAccountId}/timeTrackingEntries/{timeTrackingEntryId} | returns a single time tracking entry


## Documentation for Models

 - [KoronaCloudClient::Account](docs/Account.md)
 - [KoronaCloudClient::AccountSummary](docs/AccountSummary.md)
 - [KoronaCloudClient::AccountTransaction](docs/AccountTransaction.md)
 - [KoronaCloudClient::AddOrUpdateResult](docs/AddOrUpdateResult.md)
 - [KoronaCloudClient::AdditionalInfo](docs/AdditionalInfo.md)
 - [KoronaCloudClient::AdditionalReceiptInfoType](docs/AdditionalReceiptInfoType.md)
 - [KoronaCloudClient::AddressInformation](docs/AddressInformation.md)
 - [KoronaCloudClient::Admission](docs/Admission.md)
 - [KoronaCloudClient::Amount](docs/Amount.md)
 - [KoronaCloudClient::AmountCountData](docs/AmountCountData.md)
 - [KoronaCloudClient::Assortment](docs/Assortment.md)
 - [KoronaCloudClient::Attendance](docs/Attendance.md)
 - [KoronaCloudClient::BadRequestError](docs/BadRequestError.md)
 - [KoronaCloudClient::Capacity](docs/Capacity.md)
 - [KoronaCloudClient::Cashier](docs/Cashier.md)
 - [KoronaCloudClient::CashierRole](docs/CashierRole.md)
 - [KoronaCloudClient::CashierSummary](docs/CashierSummary.md)
 - [KoronaCloudClient::Category](docs/Category.md)
 - [KoronaCloudClient::CloudSubscription](docs/CloudSubscription.md)
 - [KoronaCloudClient::CloudSubscriptionDetails](docs/CloudSubscriptionDetails.md)
 - [KoronaCloudClient::CommodityGroup](docs/CommodityGroup.md)
 - [KoronaCloudClient::CommodityGroupSummary](docs/CommodityGroupSummary.md)
 - [KoronaCloudClient::CompanyIdentification](docs/CompanyIdentification.md)
 - [KoronaCloudClient::CreationTask](docs/CreationTask.md)
 - [KoronaCloudClient::Currency](docs/Currency.md)
 - [KoronaCloudClient::CurrencyDenomination](docs/CurrencyDenomination.md)
 - [KoronaCloudClient::CurrencyExchangeRate](docs/CurrencyExchangeRate.md)
 - [KoronaCloudClient::Customer](docs/Customer.md)
 - [KoronaCloudClient::CustomerCard](docs/CustomerCard.md)
 - [KoronaCloudClient::CustomerData](docs/CustomerData.md)
 - [KoronaCloudClient::CustomerGroup](docs/CustomerGroup.md)
 - [KoronaCloudClient::CustomerGroupSummary](docs/CustomerGroupSummary.md)
 - [KoronaCloudClient::CustomerInformation](docs/CustomerInformation.md)
 - [KoronaCloudClient::CustomerOrder](docs/CustomerOrder.md)
 - [KoronaCloudClient::DayRating](docs/DayRating.md)
 - [KoronaCloudClient::DayTimePeriod](docs/DayTimePeriod.md)
 - [KoronaCloudClient::DeliveryNote](docs/DeliveryNote.md)
 - [KoronaCloudClient::DeliveryNoteItem](docs/DeliveryNoteItem.md)
 - [KoronaCloudClient::Deposit](docs/Deposit.md)
 - [KoronaCloudClient::DeviceInformation](docs/DeviceInformation.md)
 - [KoronaCloudClient::Discount](docs/Discount.md)
 - [KoronaCloudClient::EconomicZone](docs/EconomicZone.md)
 - [KoronaCloudClient::EndOfDayStatement](docs/EndOfDayStatement.md)
 - [KoronaCloudClient::EndOfDayStatementSummary](docs/EndOfDayStatementSummary.md)
 - [KoronaCloudClient::EntryGate](docs/EntryGate.md)
 - [KoronaCloudClient::Event](docs/Event.md)
 - [KoronaCloudClient::ExternalSystemCall](docs/ExternalSystemCall.md)
 - [KoronaCloudClient::FiscalTransaction](docs/FiscalTransaction.md)
 - [KoronaCloudClient::FiscalUnit](docs/FiscalUnit.md)
 - [KoronaCloudClient::FiscalUnitCertificateInfo](docs/FiscalUnitCertificateInfo.md)
 - [KoronaCloudClient::FiscalUnitState](docs/FiscalUnitState.md)
 - [KoronaCloudClient::FiscalUnitStateUsageLevel](docs/FiscalUnitStateUsageLevel.md)
 - [KoronaCloudClient::FiscalUnitStateUsageLevelValue](docs/FiscalUnitStateUsageLevelValue.md)
 - [KoronaCloudClient::FiscalUnitStateVersionInfo](docs/FiscalUnitStateVersionInfo.md)
 - [KoronaCloudClient::ForbiddenError](docs/ForbiddenError.md)
 - [KoronaCloudClient::GeoLocation](docs/GeoLocation.md)
 - [KoronaCloudClient::InfoText](docs/InfoText.md)
 - [KoronaCloudClient::Interval](docs/Interval.md)
 - [KoronaCloudClient::Inventory](docs/Inventory.md)
 - [KoronaCloudClient::InventoryList](docs/InventoryList.md)
 - [KoronaCloudClient::InventoryListItem](docs/InventoryListItem.md)
 - [KoronaCloudClient::InventoryListItemStock](docs/InventoryListItemStock.md)
 - [KoronaCloudClient::KoronaAccount](docs/KoronaAccount.md)
 - [KoronaCloudClient::MediaUrl](docs/MediaUrl.md)
 - [KoronaCloudClient::MethodNotAllowedError](docs/MethodNotAllowedError.md)
 - [KoronaCloudClient::ModelReference](docs/ModelReference.md)
 - [KoronaCloudClient::NotFoundError](docs/NotFoundError.md)
 - [KoronaCloudClient::OpeningHours](docs/OpeningHours.md)
 - [KoronaCloudClient::OrganizationalUnit](docs/OrganizationalUnit.md)
 - [KoronaCloudClient::Payment](docs/Payment.md)
 - [KoronaCloudClient::PaymentMethod](docs/PaymentMethod.md)
 - [KoronaCloudClient::PaymentSummary](docs/PaymentSummary.md)
 - [KoronaCloudClient::Period](docs/Period.md)
 - [KoronaCloudClient::PeriodListTopSeller](docs/PeriodListTopSeller.md)
 - [KoronaCloudClient::PeriodMapStringRevenueData](docs/PeriodMapStringRevenueData.md)
 - [KoronaCloudClient::PeriodObject](docs/PeriodObject.md)
 - [KoronaCloudClient::PeriodRevenueData](docs/PeriodRevenueData.md)
 - [KoronaCloudClient::Pos](docs/Pos.md)
 - [KoronaCloudClient::PriceGroup](docs/PriceGroup.md)
 - [KoronaCloudClient::Product](docs/Product.md)
 - [KoronaCloudClient::ProductCode](docs/ProductCode.md)
 - [KoronaCloudClient::ProductDescription](docs/ProductDescription.md)
 - [KoronaCloudClient::ProductPrice](docs/ProductPrice.md)
 - [KoronaCloudClient::ProductStock](docs/ProductStock.md)
 - [KoronaCloudClient::ProductSubproduct](docs/ProductSubproduct.md)
 - [KoronaCloudClient::ProductSupplierPrice](docs/ProductSupplierPrice.md)
 - [KoronaCloudClient::ProductTransferInvolvedPartyInformation](docs/ProductTransferInvolvedPartyInformation.md)
 - [KoronaCloudClient::ProductTransferInvolvedPartyInformationData](docs/ProductTransferInvolvedPartyInformationData.md)
 - [KoronaCloudClient::ProductionType](docs/ProductionType.md)
 - [KoronaCloudClient::Rating](docs/Rating.md)
 - [KoronaCloudClient::Receipt](docs/Receipt.md)
 - [KoronaCloudClient::ReceiptItem](docs/ReceiptItem.md)
 - [KoronaCloudClient::ReceiptMaxRevisions](docs/ReceiptMaxRevisions.md)
 - [KoronaCloudClient::ResultList](docs/ResultList.md)
 - [KoronaCloudClient::ResultListAccount](docs/ResultListAccount.md)
 - [KoronaCloudClient::ResultListAdditionalReceiptInfoType](docs/ResultListAdditionalReceiptInfoType.md)
 - [KoronaCloudClient::ResultListAssortment](docs/ResultListAssortment.md)
 - [KoronaCloudClient::ResultListAttendance](docs/ResultListAttendance.md)
 - [KoronaCloudClient::ResultListCashier](docs/ResultListCashier.md)
 - [KoronaCloudClient::ResultListCashierRole](docs/ResultListCashierRole.md)
 - [KoronaCloudClient::ResultListCommodityGroup](docs/ResultListCommodityGroup.md)
 - [KoronaCloudClient::ResultListCreationTask](docs/ResultListCreationTask.md)
 - [KoronaCloudClient::ResultListCurrency](docs/ResultListCurrency.md)
 - [KoronaCloudClient::ResultListCustomer](docs/ResultListCustomer.md)
 - [KoronaCloudClient::ResultListCustomerGroup](docs/ResultListCustomerGroup.md)
 - [KoronaCloudClient::ResultListCustomerOrder](docs/ResultListCustomerOrder.md)
 - [KoronaCloudClient::ResultListDayRating](docs/ResultListDayRating.md)
 - [KoronaCloudClient::ResultListDeliveryNote](docs/ResultListDeliveryNote.md)
 - [KoronaCloudClient::ResultListEconomicZone](docs/ResultListEconomicZone.md)
 - [KoronaCloudClient::ResultListEndOfDayStatement](docs/ResultListEndOfDayStatement.md)
 - [KoronaCloudClient::ResultListEntryGate](docs/ResultListEntryGate.md)
 - [KoronaCloudClient::ResultListEvent](docs/ResultListEvent.md)
 - [KoronaCloudClient::ResultListExternalSystemCall](docs/ResultListExternalSystemCall.md)
 - [KoronaCloudClient::ResultListFiscalUnit](docs/ResultListFiscalUnit.md)
 - [KoronaCloudClient::ResultListInfoText](docs/ResultListInfoText.md)
 - [KoronaCloudClient::ResultListInventory](docs/ResultListInventory.md)
 - [KoronaCloudClient::ResultListInventoryList](docs/ResultListInventoryList.md)
 - [KoronaCloudClient::ResultListInventoryListItem](docs/ResultListInventoryListItem.md)
 - [KoronaCloudClient::ResultListOrganizationalUnit](docs/ResultListOrganizationalUnit.md)
 - [KoronaCloudClient::ResultListPaymentMethod](docs/ResultListPaymentMethod.md)
 - [KoronaCloudClient::ResultListPos](docs/ResultListPos.md)
 - [KoronaCloudClient::ResultListPriceGroup](docs/ResultListPriceGroup.md)
 - [KoronaCloudClient::ResultListProduct](docs/ResultListProduct.md)
 - [KoronaCloudClient::ResultListProductStock](docs/ResultListProductStock.md)
 - [KoronaCloudClient::ResultListProductionType](docs/ResultListProductionType.md)
 - [KoronaCloudClient::ResultListReceipt](docs/ResultListReceipt.md)
 - [KoronaCloudClient::ResultListSalesTax](docs/ResultListSalesTax.md)
 - [KoronaCloudClient::ResultListSector](docs/ResultListSector.md)
 - [KoronaCloudClient::ResultListStockOrder](docs/ResultListStockOrder.md)
 - [KoronaCloudClient::ResultListStockReceipt](docs/ResultListStockReceipt.md)
 - [KoronaCloudClient::ResultListStockReceiptItem](docs/ResultListStockReceiptItem.md)
 - [KoronaCloudClient::ResultListSupplier](docs/ResultListSupplier.md)
 - [KoronaCloudClient::ResultListTag](docs/ResultListTag.md)
 - [KoronaCloudClient::ResultListTicket](docs/ResultListTicket.md)
 - [KoronaCloudClient::ResultListTicketDefinition](docs/ResultListTicketDefinition.md)
 - [KoronaCloudClient::ResultListTimeTrackingEntity](docs/ResultListTimeTrackingEntity.md)
 - [KoronaCloudClient::ResultListTimeTrackingEntry](docs/ResultListTimeTrackingEntry.md)
 - [KoronaCloudClient::RevenueData](docs/RevenueData.md)
 - [KoronaCloudClient::SalesTax](docs/SalesTax.md)
 - [KoronaCloudClient::SalesTaxRate](docs/SalesTaxRate.md)
 - [KoronaCloudClient::Sector](docs/Sector.md)
 - [KoronaCloudClient::SectorRevenueAccountItem](docs/SectorRevenueAccountItem.md)
 - [KoronaCloudClient::SectorSalesTaxItem](docs/SectorSalesTaxItem.md)
 - [KoronaCloudClient::Service](docs/Service.md)
 - [KoronaCloudClient::Signature](docs/Signature.md)
 - [KoronaCloudClient::Statistic](docs/Statistic.md)
 - [KoronaCloudClient::StatisticListTopSeller](docs/StatisticListTopSeller.md)
 - [KoronaCloudClient::StatisticMapStringRevenueData](docs/StatisticMapStringRevenueData.md)
 - [KoronaCloudClient::StatisticRevenueData](docs/StatisticRevenueData.md)
 - [KoronaCloudClient::StockOrder](docs/StockOrder.md)
 - [KoronaCloudClient::StockOrderItem](docs/StockOrderItem.md)
 - [KoronaCloudClient::StockReceipt](docs/StockReceipt.md)
 - [KoronaCloudClient::StockReceiptItem](docs/StockReceiptItem.md)
 - [KoronaCloudClient::StockReceiptItemAmount](docs/StockReceiptItemAmount.md)
 - [KoronaCloudClient::StockReceiptItemIdentification](docs/StockReceiptItemIdentification.md)
 - [KoronaCloudClient::StockReceiptItemPurchasePrice](docs/StockReceiptItemPurchasePrice.md)
 - [KoronaCloudClient::Supplier](docs/Supplier.md)
 - [KoronaCloudClient::SupplierContact](docs/SupplierContact.md)
 - [KoronaCloudClient::SupplierContactPerson](docs/SupplierContactPerson.md)
 - [KoronaCloudClient::SupplierPaymentInformation](docs/SupplierPaymentInformation.md)
 - [KoronaCloudClient::Tag](docs/Tag.md)
 - [KoronaCloudClient::TaxPayment](docs/TaxPayment.md)
 - [KoronaCloudClient::TaxSummary](docs/TaxSummary.md)
 - [KoronaCloudClient::Ticket](docs/Ticket.md)
 - [KoronaCloudClient::TicketData](docs/TicketData.md)
 - [KoronaCloudClient::TicketDefinition](docs/TicketDefinition.md)
 - [KoronaCloudClient::TicketPersonalization](docs/TicketPersonalization.md)
 - [KoronaCloudClient::TimePeriod](docs/TimePeriod.md)
 - [KoronaCloudClient::TimeTrackingEntity](docs/TimeTrackingEntity.md)
 - [KoronaCloudClient::TimeTrackingEntry](docs/TimeTrackingEntry.md)
 - [KoronaCloudClient::TooManyRequestsError](docs/TooManyRequestsError.md)
 - [KoronaCloudClient::TopSeller](docs/TopSeller.md)
 - [KoronaCloudClient::TotalPeriod](docs/TotalPeriod.md)
 - [KoronaCloudClient::TotalPrice](docs/TotalPrice.md)
 - [KoronaCloudClient::Validity](docs/Validity.md)
 - [KoronaCloudClient::VoidedReceiptItem](docs/VoidedReceiptItem.md)
 - [KoronaCloudClient::Weather](docs/Weather.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

